List all metrics from the dbt Semantic Layer.

If the user is asking a data-related or business-related question,
this tool should be used as a first step to get a list of metrics
that can be used with other tools to answer the question.

Examples:
- "What are the top 5 products by revenue?"
- "How many users did we have last month?"

<parameters>
search: Optional string used to filter metrics by name using partial matches
</parameters>